@@ -1,10 +1,19 @@
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json  # Python 2.5
+
 from django.db import models
-from django.utils import simplejson
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
 
 class TableFormatter(object):
+    """
+    Table formatter which should convert a structure of nested lists into
+    a suitable HTML table representation.
+    """
+
     def __init__(self, **kwargs):
         for k, v in kwargs.items():
             setattr(self, k, v)
@@ -38,6 +47,15 @@ class TitleTableFormatter(TableFormatter):
 
 
 class TableContent(models.Model):
+    """
+    Content to edit and display HTML tables in the CMS.
+
+    The standard rich text editor configuration in FeinCMS does not activate
+    the table plugin. This content type can be used to edit and display
+    nicely formatted HTML tables. It is easy to specify your own table
+    renderers.
+    """
+
     feincms_item_editor_includes = {
         'head': ['admin/content/table/init.html'],
         }
@@ -77,6 +95,7 @@ class TableContent(models.Model):
     def save(self, *args, **kwargs):
         # XXX ugly, but otherwise the decoder raises exceptions
         self.data = self.data.replace('\r', '\\r').replace('\n', '\\n').replace('\t', '\\t')
-        self.html = self.data and self.FORMATTERS[self.type](simplejson.loads(self.data)) or u''
+        self.html = self.data and self.FORMATTERS[self.type](json.loads(self.data)) or u''
 
         super(TableContent, self).save(*args, **kwargs)
+    save.alters_data = True
