@@ -5,7 +5,6 @@ All models defined here are abstract, which means no tables are created in
 the feincms\_ namespace.
 """
 
-import itertools
 import operator
 import warnings
 
@@ -21,20 +20,9 @@ from django.utils.datastructures import SortedDict
 from django.utils.encoding import force_unicode
 from django.utils.translation import ugettext_lazy as _
 
-from feincms import settings, ensure_completely_loaded
+from feincms import ensure_completely_loaded
 from feincms.utils import get_object, copy_model_instance
 
-try:
-    import reversion
-except ImportError:
-    reversion = None
-
-try:
-    any
-except NameError:
-    # For Python 2.4
-    from feincms.compat import c_any as any
-
 
 class Region(object):
     """
@@ -321,15 +309,26 @@ class ExtensionsMixin(object):
                         try:
                             fn = get_object('%s.%s.register' % (path, ext))
                             if fn:
+                                warnings.warn(
+                                    'Using short names for extensions has been deprecated'
+                                    ' and will be removed in FeinCMS v1.8.'
+                                    ' Please provide the full python path to the extension'
+                                    ' %s instead (%s.%s).' % (ext, path, ext),
+                                    DeprecationWarning, stacklevel=2)
+
                                 break
-                        except ImportError, e:
+                        except ImportError:
                             pass
 
                 if not fn:
                     raise ImproperlyConfigured, '%s is not a valid extension for %s' % (
                         ext, cls.__name__)
 
-            # Not a string, so take our chances and just try to access "register"
+            # Not a string, maybe a callable?
+            elif hasattr(ext, '__call__'):
+                fn = ext
+
+            # Take our chances and just try to access "register"
             else:
                 fn = ext.register
 
@@ -407,7 +406,7 @@ def create_base_model(inherit_from=models.Model):
                 cls._feincms_templates = SortedDict()
                 cls.TEMPLATES_CHOICES = []
 
-            instances = getattr(cls, '_feincms_templates', SortedDict())
+            instances = cls._feincms_templates
 
             for template in templates:
                 if not isinstance(template, Template):
@@ -443,7 +442,6 @@ def create_base_model(inherit_from=models.Model):
             for template in cls._feincms_templates.values():
                 cls._feincms_all_regions.update(template.regions)
 
-
         #: ``ContentProxy`` class this object uses to collect content blocks
         content_proxy_class = ContentProxy
 
@@ -509,7 +507,7 @@ def create_base_model(inherit_from=models.Model):
                 if 'request' in kwargs:
                     request = kwargs['request']
 
-                    if request.session and request.session.get('frontend_editing'):
+                    if request.COOKIES and request.COOKIES.get('frontend_editing'):
                         return render_to_string('admin/feincms/fe_box.html', {
                             'content': self.render(**kwargs),
                             'identifier': self.fe_identifier(),
@@ -731,27 +729,6 @@ def create_base_model(inherit_from=models.Model):
                 for key, includes in model.feincms_item_editor_includes.items():
                     cls.feincms_item_editor_includes.setdefault(key, set()).update(includes)
 
-            # Ensure meta information concerning related fields is up-to-date.
-            #
-            # Upon accessing the related fields information from Model._meta, the related
-            # fields are cached and never refreshed again (because models and model relations
-            # are defined upon import time, if you do not fumble around with models like we
-            # do right here.)
-            #
-            # Adding related models after this information has been cached leads to models
-            # not knowing about related items, which again causes the bug we had in
-            # issue #63 on github:
-            #
-            # http://github.com/feincms/feincms/issues/issue/63/
-            #
-            # Currently, all methods filling up the Model.meta cache start with fill_.
-            # We call all these methods upon creation of a new content type to make sure
-            # that we really really do not forget a relation somewhere. Of course, we do
-            # too much here, but better a bit too much upon application startup than not
-            # enough like before.
-            for fn in [s for s in dir(cls._meta) if s[:6]=='_fill_']:
-                getattr(cls._meta, fn)()
-
             return new_type
 
         @property
@@ -779,6 +756,8 @@ def create_base_model(inherit_from=models.Model):
 
         @classmethod
         def _needs_templates(cls):
+            ensure_completely_loaded()
+
             # helper which can be used to ensure that either register_regions or
             # register_templates has been executed before proceeding
             if not hasattr(cls, 'template'):
@@ -820,8 +799,11 @@ def create_base_model(inherit_from=models.Model):
 
         @classmethod
         def register_with_reversion(cls):
-            if not reversion:
+            try:
+                import reversion
+            except ImportError:
                 raise EnvironmentError("django-reversion is not installed")
+
             follow = []
             for content_type_model in cls._feincms_content_types:
                 related_manager = "%s_set" % content_type_model.__name__.lower()
